@@ -23,6 +23,9 @@ from typing_extensions import Literal
 from .exceptions import InvalidArgument, handle_agent_exceptions
 from .cancellable_stream_thread import CancellableStreamThread
 
+import os
+
+DEFAULT_AGENT_URL = "unix:///var/lib/formant/agent.sock"
 DEFUALT_IMAGE_CONTENT_TYPE = "image/jpg"  # type: Literal["image/jpg"]
 DEFAULT_SEVERITY_TYPE = "info"  # type: Literal["info"]
 ALLOWED_IMAGE_CONTENT_TYPES = ["image/jpg", "image/jpeg", "image/png"]
@@ -105,10 +108,11 @@ class Client:
 
     def __init__(
         self,
-        agent_url="unix:///var/lib/formant/agent.sock",  # type: str
+        agent_url=DEFAULT_AGENT_URL,  # type: str
         enable_logging=True,  # type: bool
         ignore_throttled=False,  # type: bool
         ignore_unavailable=False,  # type: bool
+        local_dev=False,  # type: bool
     ):
         """
         __init__()
@@ -133,6 +137,10 @@ class Client:
         self.ignore_unavailable = ignore_unavailable
 
         self._agent_url = agent_url  # type: str
+        if local_dev == True:
+            self._agent_url = os.getenv(
+                "FORMANT_AGENT_URL", DEFAULT_AGENT_URL
+            )  # type: str
         self._app_config = {}  # type: Dict[str, str]
         self._config_update_callbacks = []  # type: List[Callable[[], None]]
         self._command_request_callback_streams = (
@@ -308,7 +316,9 @@ class Client:
             numeric_set.numerics.extend(
                 [
                     math_pb2.NumericSetEntry(
-                        value=v[0], label=k, unit=v[1] if v[1] else None,
+                        value=v[0],
+                        label=k,
+                        unit=v[1] if v[1] else None,
                     )
                 ]
             )
@@ -734,7 +744,9 @@ class Client:
         :param datapoint: A datapoint related to the command
         """
         response = commands_pb2.CommandResponse(
-            request_id=request_id, success=success, datapoint=datapoint,
+            request_id=request_id,
+            success=success,
+            datapoint=datapoint,
         )
         request = agent_pb2.SendCommandResponseRequest(response=response)
         self.agent_stub.SendCommandResponse(request)
@@ -768,7 +780,8 @@ class Client:
         )
 
     def unregister_command_request_callback(
-        self, f,  # type: Callable[[commands_pb2.CommandRequest], None]
+        self,
+        f,  # type: Callable[[commands_pb2.CommandRequest], None]
     ):
         # type: (...) -> None
         """
@@ -834,7 +847,8 @@ class Client:
         return self.agent_stub.GetTeleopInfo(request)
 
     def register_teleop_heartbeat_callback(
-        self, f,  # type: Callable[[agent_pb2.GetTeleopHeartbeatStreamResponse], None]
+        self,
+        f,  # type: Callable[[agent_pb2.GetTeleopHeartbeatStreamResponse], None]
     ):
         # type : (...) -> None
         """
@@ -903,7 +917,8 @@ class Client:
         )
 
     def unregister_custom_data_channel_message_callback(
-        self, f,  # type: Callable[[], None]
+        self,
+        f,  # type: Callable[[], None]
     ):
         # type : (...) -> None
         """
@@ -1329,7 +1344,6 @@ class Client:
         validate_string_in_array(
             content_type, ALLOWED_IMAGE_CONTENT_TYPES, "content_type"
         )
-        validate_type(labels, [List])
         validate_type(labels, [dict])
         for label in hint:
             validate_type(label, [intervention_pb2.LabeledPolygon])
@@ -1358,7 +1372,6 @@ class Client:
     def get_intervention_response(
         self,
         request_id,  # type: str
-        timestamp=None,  # type: Optional[int]
     ):
         # type : (...) -> agent_pb2.GetInterventionResponse
 
@@ -1382,5 +1395,4 @@ class Client:
         validate_type(request_id, [str])
         response_request = agent_pb2.GetInterventionResponseRequest()
         response_request.request_id = request_id
-        response_request.timestamp = timestamp if timestamp else current_timestamp()
         return self.agent_stub.GetInterventionResponse(response_request)
